import tkinter as tk
import tkinter.ttk as ttk
import matplotlib as plt
from matplotlib.backends.backend_tkagg import FigureCanvasTkAgg
from matplotlib.figure import Figure
import pandas as pd

plt.use('TkAgg')


class App(ttk.Frame):

    def __init__(self, parent):
        super().__init__(parent)
        self.local_df = 'covid19_Thailand_Jan_2565.csv'
        self.frame = tk.Frame()
        self.df = pd.read_csv(self.local_df)
        parent.rowconfigure(0, weight=1)
        parent.columnconfigure(0, weight=1)
        self.grid(row=0, column=0, sticky="news")
        self.rowconfigure(0, weight=1)
        self.rowconfigure(1, weight=1)
        self.columnconfigure(0, weight=1)
        self.create_widgets()
        self.update_plots()

    def create_widgets(self):
        # creating a row with combobox widgets for filters
        self.frame_filter = ttk.LabelFrame(self, text="Select Filters")
        self.frame_filter.grid(row=1, column=0, sticky="NEWS")
        label1 = ttk.Label(self.frame_filter, text="Data")
        label1.grid(row=0, column=0)
        self.head_filter = ttk.Combobox(self.frame_filter, state="readonly")
        self.head_filter.bind('<<ComboboxSelected>>', self.update_filters)
        self.head_filter.grid(row=1, column=0, padx=10, pady=10)
        self.head_filter.configure(values=list(self.df.columns.unique()[1:]))

        self.btn_quit = ttk.Button(self, text="Quit", command=root.destroy)
        self.btn_quit.grid(row=2, column=0, pady=10)
        self.btn_quit = ttk.Button(self, text="Quit", command=root.destroy)

        self.figure = Figure()
        self.axes_figure = self.figure.add_subplot()

        self.fig_canvas1 = FigureCanvasTkAgg(self.figure, master=self)
        self.fig_canvas1.get_tk_widget().grid(row=0, column=0,
                                              sticky="news", padx=10, pady=10)

    def update_plots(self):
        return self.update_filters()

    def update_filters(self, event=None):
        if self.head_filter.get() == 'new_case_week1':
            return self.plot_hist('new_case_week1')
        elif self.head_filter.get() == 'new_death_week1':
            return self.plot('new_death_week1')
        elif self.head_filter.get() == 'new_case_week2':
            return self.plot_hist('new_case_week2')
        elif self.head_filter.get() == 'new_death_week2':
            return self.plot('new_death_week2')
        elif self.head_filter.get() == 'new_case_week3':
            return self.plot_hist('new_case_week3')
        elif self.head_filter.get() == 'new_death_week3':
            return self.plot('new_death_week3')
        elif self.head_filter.get() == 'new_case_week4':
            return self.plot_hist('new_case_week4')
        elif self.head_filter.get() == 'new_death_week4':
            return self.plot('new_death_week4')
        elif self.head_filter.get() == 'Male_death_week1':
            return self.plot('Male_death_week1')
        elif self.head_filter.get() == 'Female_death_week1':
            return self.plot('Female_death_week1')
        elif self.head_filter.get() == 'Male_death_week2':
            return self.plot('Male_death_week2')
        elif self.head_filter.get() == 'Female_death_week2':
            return self.plot('Female_death_week2')
        elif self.head_filter.get() == 'Male_death_week3':
            return self.plot('Male_death_week3')
        elif self.head_filter.get() == 'Female_death_week3':
            return self.plot('Female_death_week3')
        elif self.head_filter.get() == 'Male_death_week4':
            return self.plot('Male_death_week4')
        elif self.head_filter.get() == 'Female_death_week4':
            return self.plot('Female_death_week4')
        else:
            return self.plot_hist('new_case_week1')

    def plot(self, column):
        self.axes_figure.clear()
        self.figure.subplots_adjust(bottom=0.25)
        df = self.df
        df[column] = df[column].astype(float)
        df[df[column] >= 0].plot(kind='bar', ax=self.axes_figure,
                                 x='Country/Region', y=column,
                                 legend=True,
                                 title=column,
                                 xlabel='Country/Region',
                                 ylabel=column)
        self.fig_canvas1.draw()

    def plot_hist(self, column):
        
        self.axes_figure.clear()
        self.figure.subplots_adjust(bottom=0.25)
        df = self.df
        df[column] = df[column].astype(float)
        df[df[column] >= 0].plot(kind='hist', ax=self.axes_figure,
                                 x='Country/Region', y=column,
                                 legend=True,
                                 title=column,
                                 xlabel='Country/Region',
                                 ylabel=column)
        self.fig_canvas1.draw()
    
if __name__ == "__main__":
    root = tk.Tk()
    root.title("Covid-19 in Thailand")
    root.geometry("1700x1200")
    app = App(root)
    root.mainloop()